@@ -9,7 +9,8 @@ etl_extract <- function(obj, ...) UseMethod("etl_extract")
 
 etl_extract.default <- function(obj, ...) {
   # download the data from the Internet
-  warning(paste0("No available methods. Did you write the method etl_extract.", class(obj)[1]), "()?")
+  warning(paste0("No available methods. Did you write the method etl_extract.",
+                 class(obj)[1]), "()?")
   invisible(obj)
 }
 
@@ -20,7 +21,7 @@ etl_extract.default <- function(obj, ...) {
 
 etl_extract.etl_mtcars <- function(obj, ...) {
   message("Extracting raw data...")
-  raw_filename <- paste0(attr(obj, "raw_dir"), "/mtcars.csv")
+  raw_filename <- file.path(attr(obj, "raw_dir"), "mtcars.csv")
   utils::write.csv(datasets::mtcars, file = raw_filename)
   invisible(obj)
 }
